from .utils.logging import configure_logging

configure_logging(std_formatter="simple")
